@@ -50,7 +50,7 @@ function gen_sim_where()
 	if($_REQUEST['chkAll0']) {
 		$where=" where 1";
 	}else if($_REQUEST['sim_name']){
-		$where=" where sim_name='".$_REQUEST['sim_name']."' ";
+		$where=" where sim_name in (".$_REQUEST['sim_name'].") ";
 	}else {
 		$id=get_id();
 		if(!$id) WriteErrMsg("Not choose one SIM Slot!");
@@ -224,8 +224,9 @@ if(isset($_GET['action'])) {
 		$remain_time=$_POST['remain_time'];
 		$time_unit=$_POST['time_unit'];
 		$imei_mode=$_POST['imei_mode'];
-		//$where=gen_sim_where();
+		$where=gen_sim_where();
 		if($remain_time == "" || $remain_time < -1) $remain_time=-1;
+		if($_POST[time_limit] == "" || $_POST[time_limit] < -1) $_POST[time_limit]=-1;
                 if($_POST[no_ring_limit] == "" || $_POST[no_ring_limit] < -1) $_POST[no_ring_limit]=-1;
                 if($_POST[no_answer_limit] == "" || $_POST[no_answer_limit] < -1) $_POST[no_answer_limit]=-1;
                 if($_POST[short_call_limit] == "" || $_POST[short_call_limit] < -1) $_POST[short_call_limit]=-1;
@@ -241,18 +242,18 @@ if(isset($_GET['action'])) {
 			$sql="UPDATE sim SET ";
 			if($_POST['team_id_modify']) $sql.="sim_team_id='$team_id',";
 			if($_POST['imei_mode_modify']) $sql.="imei_mode='$imei_mode',";
-			if($_POST['time_limit_modify']) $sql.="time_limit='$_POST[time_limit]',";
-			if($_POST['count_limit_modify']) $sql.="count_limit='$_POST[count_limit]',";
-			if($_POST['no_connected_limit_modify']) $sql.="no_connected_limit='$_POST[no_connected_limit]',";
+			if($_POST['time_limit_modify']) $sql.="time_limit='$_POST[time_limit]',remain_time='$_POST[time_limit]',";
+			if($_POST['count_limit_modify']) $sql.="count_limit='$_POST[count_limit]',count_remain=$_POST[count_limit],";
+			if($_POST['no_connected_limit_modify']) $sql.="no_connected_limit='$_POST[no_connected_limit]',no_connected_remain=$_POST[no_connected_limit],";
 			if($_POST['time_unit_modify']) $sql.="time_unit='$time_unit',";
 			if($_POST['no_ring_modify']) $sql.="no_ring_limit='$_POST[no_ring_limit]',no_ring_disable='$_POST[no_ring_disable]',";
 			if($_POST['no_answer_modify']) $sql.="no_answer_limit='$_POST[no_answer_limit]',no_answer_disable='$_POST[no_answer_disable]',";
 			if($_POST['short_call_modify']) $sql.="short_call_limit='$_POST[short_call_limit]',short_call_disable='$_POST[short_call_disable]',";
 			if($_POST['short_time_modify']) $sql.="short_time='$_POST[short_time]',";
 			if($_POST['dev_disable_modify']) $sql.="dev_disable='$dev_disable',";
-			if($_POSY['auto_reset_remain_modify']) $sql.="auto_reset_remain='$_POST[auto_reset_remain]'";
-			if($_POSY['auto_reset_remain_s_modify']) $sql.="auto_reset_remain_s='$_POST[auto_reset_remain_s]'";
-			$sql.="sim_login=sim_login where sim_name in ($sim_name)";
+			if($_POSY['auto_reset_remain_modify']) $sql.="auto_reset_remain='$_POST[auto_reset_remain]',";
+			if($_POSY['auto_reset_remain_s_modify']) $sql.="auto_reset_remain_s='$_POST[auto_reset_remain_s]',";
+			$sql.="sim_login=sim_login $where";
 			$db->query($sql);
 
                         $query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name $where");
@@ -264,7 +265,7 @@ if(isset($_GET['action'])) {
 				$send[]=my_pack($row, SIM_ADD);
 				if($row['imei_mode']==3) $send[]=my_pack($row, IMEI_IMSI_INFO);
 				if($_POST['dev_disable_modify']) $send[]=my_pack2($row[dev_disable]?DEV_DISABLE:DEV_ENABLE, $row[sim_name], TYPE_SIM);
-				if($_POST['team_id_modify'] && $team_id) $send[]=my_pack2(DEV_BINDING, $sim_name, 0);
+				if($_POST['team_id_modify'] && $team_id) $send[]=my_pack2(DEV_BINDING, $row[sim_name], 0);
 
 			}
 
@@ -426,7 +427,7 @@ if(isset($_GET['action'])) {
 				$row['remain_state'] = '<font color="#FF8000">Warning</font>';
 			}
 			$row['limit_state'] = '<font color="#00FF00">Enough</font>';
-			if(($row['no_ring_remain'] >= $row['no_ring_limit'] && $row['no_ring_limit']!=-1)|| ($row['no_answer_remain']>=$row['no_answer_limit'] && $row['no_answer_limit']!=-1) || ($row['short_call_remain'] > $row['short_call_limit'] && $row['short_call_limit']!=-1)){
+			if(($row['no_ring_remain'] >= $row['no_ring_limit'] && $row['no_ring_limit']!=-1)|| ($row['no_answer_remain']>=$row['no_answer_limit'] && $row['no_answer_limit']!=-1) || ($row['short_call_remain'] >= $row['short_call_limit'] && $row['short_call_limit']!=-1)){
 				$row['limit_state'] = '<font color="#FF8000">Warning</font>';
 			}
 			$rsdb[]=$row;
