@@ -278,6 +278,10 @@
 	@$db->updatequery("ALTER TABLE `sim` ADD `auto_reset_remain` int(1) NOT NULL default '0'");
 	@$db->updatequery("ALTER TABLE `sim` ADD `auto_reset_remain_s` int(11) NOT NULL default '60'");
 	@$db->updatequery("ALTER TABLE `sim_bank` ADD  `type` varchar(32) NOT NULL default 'SMB32'");
+
+	@$db->updatequery("ALTER TABLE  `system` CHANGE  `auto_disable_s_call_msg`  `auto_disable_s_call_msg` VARCHAR( 256 ) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT 'Unassigned (unallocated) number'");
+
+	@$db->updatequery("ALTER TABLE `sim` ADD `last_call_msg` varchar(256) NOT NULL");
 	echo "update done! <a href=''  target=_top>Return</a>";
 
 
